@@ -93,7 +93,7 @@ This specifies three options that may be on the command line. They are
 
  sbin/echo-server.pl
 
- XAS
+L<XAS|XAS>
 
 =head1 AUTHOR
 
