@@ -148,7 +148,7 @@ The acknowledgement to send back to the message queue server.
 
 =head1 SEE ALSO
 
- XAS
+L<XAS|XAS>
 
 =head1 AUTHOR
 
