@@ -250,7 +250,7 @@ Become a daemon.
 
 =head1 SEE ALSO
 
- XAS
+L<XAS|XAS>
 
 =head1 AUTHOR
 
