@@ -144,7 +144,7 @@ An optional IP port to connect too.
 
 =head1 SEE ALSO
 
- XAS
+L<XAS|XAS>
 
 =head1 AUTHOR
 
