@@ -120,7 +120,7 @@ The exception that is to be handled.
 
 =head1 SEE ALSO
 
- XAS
+L<XAS|XAS>
 
 =head1 AUTHOR
 
